@@ -30,5 +30,20 @@ module SemverDialects
         exit(ecode)
       end
     end
+
+    desc 'sort TYPE VERSIONS...', 'Sort a list of versions according to the specified package type'
+    method_option :help, aliases: '-h', type: :boolean,
+                         desc: 'Display usage information'
+    method_option :json, type: :boolean,
+                         desc: 'Output results in JSON format'
+    def sort(type, *versions)
+      if options[:help]
+        invoke :help, ['sort']
+      else
+        require_relative 'commands/sort_versions'
+        ecode = SemverDialects::Commands::SortVersions.new(type, versions, options).execute
+        exit(ecode)
+      end
+    end
   end
 end
